
# q-expansion of newform 75.16.a.l, downloaded from the LMFDB on 15 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 75
weight = 16
poly_data = [962566763029600000, 11942226547624000, -240460263995200, -638065050800, 12902022496, 5065964, -206884, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0], 1], [[-51726, 35, 1, 0, 0, 0, 0, 0], 1], [[-2049391066485603712, -923236766383772512, -550595900855376, 51802225233488, 2890812920, -683774226, 31693, 2581], 11388268099584], [[25273736743865445760, -13516614415608992, 505042828457040, -40413957133904, -2890812920, 683774226, -31693, -2581], 11388268099584], [[4012290659675216042368, 22272397257755236064, -436401078014545104, -994182620045168, 9939087037640, 13639097274, -58895923, -56903], 45553072398336], [[2939625300658590017152, 61929390561475054624, -308522430014060016, -4599151185198416, 8587020066616, 87901444566, -55931569, -473989], 22776536199168], [[-8469445244380839833728, -190108228934657085856, 1070016176478681072, 14298910799326928, -34056074566936, -269464422942, 235564033, 1430365], 45553072398336]]

hecke_ring_character_values = None
aps_data = [[34, 1, 0, 0, 0, 0, 0, 0], [2187, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0], [143558, 644, -4, 1, 0, 0, 0, 0], [7795978, 58269, 474, 7, 3, -1, 3, 0], [5555669, 39674, -1954, 5, -4, -3, 8, -4], [449195557, 41548, -8406, -39, -6, -9, 6, 36], [-62351319, 1927545, -35768, 1282, 185, -36, -67, 44], [290478265, 35433789, 96644, 1098, -947, -168, -527, 144], [4589690421, -88759171, -550016, -14593, -5623, -2576, -2947, 0], [20855079141, -119945769, -893548, -18844, -9533, 2250, 5623, 3172], [312320934003, -566209482, 9087234, 26147, -37388, -2445, -3416, -1820], [594054166082, 1949851968, -6478008, 66866, 116376, -3584, 3192, -13968], [164225081014, -3809209346, -6138656, -250780, -66234, 13788, 35214, 14784], [-376349484131, 2953466881, 38237428, -626200, 83985, -66084, 83701, 42768], [870051966804, 13755239791, -59088710, -744963, 523637, 51747, 119069, -137016], [150288562104, 55668925183, -263910046, -3546317, -1696643, -162613, -397739, -133128], [3200641762866, 46588439280, 39282848, 2688752, -1024256, -189720, 554848, -36176], [-3368138429030, -65254341746, -376174376, 7662634, 184942, 920964, 2144950, 155584], [-21791564846238, 151865321688, -197546364, 14552322, 2247732, 791454, -375156, 717912], [13393648582356, -133480780062, -343031484, 752714, 2628478, -1778658, -2553122, -956384], [21609546732819, 441297145905, -1516082804, 19131708, -10838091, 3820014, 1162113, -321204], [108610480265196, -37062610772, 423073336, -23906160, 463172, 7605348, 2543300, 975312], [-54684738144760, 735506709706, 1064908232, -1168572, -16203782, 949368, 18030370, 3977136], [-132942236189704, -1407761075692, -4745341912, -1190032, -31869988, 4025580, 9305276, -11408272], [-237627934393131, -765355171343, -29775687664, 48945565, 88902109, 6784196, 13670161, -6493824], [280578422433440, -982929391642, -7136143804, -86636015, 88450818, -3401064, -9470262, 1712832], [-227829674767222, -1498207148922, -25701592648, 338613776, 64931270, -1507176, 11149278, 23582016], [460492698804336, -5780731697778, 5550884512, 310501190, 36179494, -2788848, 10802014, -13887248], [1131663535294649, -2713017508294, -30572862250, 128884687, 64746204, 11555025, -32678008, 5186916], [1639509043217568, -4799929226610, 23571076452, 682572525, -262236918, -174611952, -65853678, -6144672], [-2376473232616834, 1249032886227, 7205481270, -1031562379, 724184397, -129934391, -101460627, 75010320], [4585627692417683, 14122434635940, 115533927430, -1905310593, -647160442, -43346415, -38747686, 122040828], [-256157170031585, -158733792315, 111724563468, 232253260, -568788991, 84111066, -255556627, -164727436], [4810456964940537, 17284193528845, -84927381376, 1043807107, -817604135, -273536152, -8439635, 302674752], [-2899751215258681, -18586041436539, -105545636724, -2003165596, -1036342439, 528533190, -347347115, 23758828], [3935973325369597, -64081582667378, -522803075402, 940663233, 2688333848, 55912929, -834876412, -81450820], [16667440353490500, 2875311147276, -233232698904, 7658864678, 2668016260, -433874616, 772955188, 683686432], [-368058362147891, 130831595908045, -358896941556, -1494223290, 2446670373, 788376204, 1222672857, 475040592], [13671992639525102, 38915696876771, -780664463994, -4222334781, -3839016003, 507526461, -2235912675, -569901312], [40164998848220118, 113490782889453, 750967163442, -1782080457, -1504627893, 98741715, -138174309, 768461472], [9620155847895336, -81663290036826, -1090412015056, 7199149942, -2158337458, -624163896, -783661114, 272847440], [47413751492570012, -311790693284074, 67431452140, 14070507034, -9010437910, -112840990, -532441750, 12315456], [-15717846736757980, -359766882387670, 280228983092, 30991542, -5069213498, -1906714122, -2327518202, 349585360], [59904349838707748, 237884398344423, 1083935326378, -1189017543, 850073453, -383114469, 225345461, -605614536], [35127512491546555, -436767494808735, -1366992045252, 25059891516, 9386927157, 407187270, -3252831135, 2442458028], [-38663963000885325, -300710660992143, 4588641212156, 25744207580, 19643857597, 3979217106, 5568242041, 2986869508], [-224870028369350534, 17993648761816, 4879338595804, 63766661073, 18946624004, 1599499608, 6246011252, -932013856], [-215189923749034888, 402052204478544, -5387882048600, -130085753040, -17523025528, -2894869596, 13558050008, 2358855504], [6624785073613632, -1044240304050318, 1128152995120, -81210202954, 2886182890, -192873168, 8868048370, -2075719280], [-253839956989690889, 57324844923618, -3093992899790, -190963370555, -23561760200, -1880090613, -13037487828, 4932197244], [-88232337064134492, -880166716596278, -2528556888556, 104799610054, -11541954314, 10696426718, 16126568950, 5914539072], [184637886864135258, -2581602347009148, -2429044244848, -154426214900, -29773478860, -7724940336, -2222581372, -1745043664], [-295388203292437576, -1938230129867627, -17619897704074, -41457014547, 14454506479, -13260080199, -26652586121, 15666097752], [35250661174207141, 296130657061042, 8486886953118, -2940705189, -121469100276, 4903882173, -3808394616, -13176928908], [-187254221157483961, 968716735792367, 22432055785556, -284584990538, 89718288423, -509974140, 14579575715, 10755417168], [-556655752110295681, 2608005209641711, -18474253651456, -541173088071, 75469914067, 10183027032, 32069202031, 5494275936], [438332115795754539, -2774125398475131, -8801375677900, -41341470448, 88488215041, 19422019818, 21135972685, -36897244820], [570963921732970865, 309418216298456, -7171458745174, -344210712973, 85145351054, -33663839385, 36683505530, 459198428], [-498211198977985090, -4296357662350672, 30373015519504, -19391152484, -113669414944, 20141046800, -66760735072, 7772825376], [177889495633761758, 512809569304994, -14407737054568, 108268028338, -146605909230, 31721751036, 38753199306, 15269370912], [593328325102608624, 5110380824502403, -2274977627462, -181975053807, 183808786313, 6759059451, 28312518785, -1261175976], [-553840602385536168, 9144397906166028, -24488557890336, 52553034508, -78092819236, -5321972208, 14445593804, 47019718304], [-1286223003148241684, -13195260982533722, 26643437457260, 981548682026, 18103325050, -131567911742, 74999796730, 3222961920], [1982317988370511924, -4636042411016366, -95329838336444, -206633912794, -137730472290, -66511154754, 132531101982, 18449436816], [817981357822993860, -6764793354781771, 2114110671566, -887055039621, 245588592631, 57279731673, 6166229167, 31630016520], [-34823195916273493, -17758434685472469, 13832063929752, 990593421686, 211559275675, 47408850540, -46486243385, -11476127180], [7531268517206380444, 20466292335227854, -37499103437924, 84390690926, -87070653870, 121969455138, -230742559374, -20256785952], [4756465423339805614, -36965460143239034, -11824924493984, -1683216374488, -600606820482, 34428093420, 66254947558, 18228920400], [834601147955728086, -12407175727199292, -97347163404464, -1515954788900, 397425399668, -217669303440, -409421365948, 54509098736], [2940566590195752047, -8350320516938806, -147231661627246, 1388882923477, -918324329376, -423642461205, 137886531572, -9035313156], [-5615354880511907990, 19361546507414198, 189610927973656, 2328012216744, 878547336638, 88658493276, 64536607142, -24823565784], [982166148559298828, 33772794769892114, -125096955170812, -2907095451051, -647556130562, -259739256552, -389923037450, -248179420544], [-512310901732973899, 8956318839661358, 66384172762886, 2694457363977, -656128683800, 207284109177, 864661825780, 209098503964], [5295689067312181857, 28023835729866783, -56326950175988, 279172079736, -2849595571941, -64952157582, 239356365807, 374475116028], [1843491403365895901, -32296620140649019, -177067995878340, 1989477934632, 1158058561293, 206868597408, -618773291631, 241116984144], [-13267624770948080377, 51079275123236631, 157762481473440, -6629004038005, -558119413989, 170118137044, 27250510311, 176788474848], [1381393103559690129, 20264106135621084, -244644701437902, -7626904130025, 854433231978, -327992086125, -194086154346, 517915887996], [-23615144894577825786, 61237597358532824, -136897148902328, -4725816376186, 553371314960, -195610775000, 1425815778992, -404444156688], [9224081841997096974, 66104937920908068, -401997369706064, -5485124647350, 40847380020, -568025753868, -378594300492, -776206818288], [-20259291038749586384, 27992801333209593, 346023744545886, 12483935932369, -1311783863253, 285315048965, 38944026291, 538049213784], [14579376422478775800, 83234664954950466, 470141863417376, 11440530823022, 575956635274, 576198295128, 924156854002, 249004242736], [-3513128850436279690, 125700004687212442, -92070894871864, 12040792137144, 5330858857522, 53241718932, -1304677970294, 124367157720], [-12183822764307459450, 60050915276849928, 452918755727148, 648208486730, -2412302469668, -672457139790, -1882080908444, 28833786856], [39628688490012205023, -85362281839144083, -118269985875092, 12886210914116, -821373971567, 378150667758, 2241683354317, -500684554052], [1899556919598521044, 90336151556595804, 735331230754952, -7306836331860, 2421359581540, 1294898512980, 193920519844, -159657100560], [-23254338006397201208, 9229677450989138, 1702981937171440, 11217828031734, 4166623518266, -383627949240, -534371030878, -750664488384], [19008896045311419836, -36706320057321052, 786050268543632, 5131887436300, 4946907343716, 1332272551032, -6909998220, 944382028032], [10907640496418307101, 6389896451748425, 399683024021296, -1840634967065, -8389706992747, -602609402320, -542961940999, 738197547264], [21079603152707320124, -49726239593018746, 285325938845564, 24383438587375, 14277671235642, 389190241296, 660306381186, 107757046848], [17397608092475604406, 178712428945480462, -153293202822912, 7989428821848, 2342188326726, -2944716415668, -4925487475122, 101005927056], [-43279846460931694106, -101057936514745232, 943484731376060, -40832342673418, -5583600640652, 1379297121826, 4699493999740, 40569357672], [38750358818136468816, -221120551114372350, -995371215090324, 8539868651495, 2377623458230, -974342301936, 7380477228334, -542012436992], [31804179532897653980, 224899289295664905, 2178350959314870, -33023871698191, -4278628699245, 1084442752873, -3105892355157, -51972624936], [57356739358706182035, 344814969355921887, 87166438806016, 6790399188634, 9467976160583, -293990005368, 2690403037811, -1242697712236], [91537208706609398197, 254016419316903561, -27794496171292, 21896633571276, 5059851265417, 780675902940, -737729949107, 3495510860400], [-66125938239534064133, 659757571558256895, 2187192974028096, 7931499458419, 10811325588099, -3392569118812, -7659135371217, 605634219360], [-53755724884702795584, 567178534685039922, 2459877413281200, 31986478036686, 2296315644570, 4673909195736, 7373219588802, -711154285056], [122820614955852193032, -366284764605210888, -470726321910360, -20161830102698, -4970142738592, -280763798304, 4508359421792, -3462203833792], [-74712056393828566888, 60704013449123406, -2624451616845936, -67891189307634, -14316472203498, 2589182983944, 3447863115822, 4449542045616], [127421577070632180818, -650237968967277982, 1994669796970256, -22118915210804, 1481906057418, -1976914210356, -2816400118878, 572466395520], [211482540341773953254, 386896529296471497, -2609835615718582, -37876308228307, 27270168536255, -3157982662149, -9986205528273, -942153608592], [115052310634599390398, -692981142521118898, -231658581342784, -97974884420624, 7433368141542, 8741085149580, 1574446298222, 2770460188848], [-96745667007952864590, -490214822528461924, -6287597255579336, 158992273625090, 4728205807508, -2013206274272, 5197731307556, -6702219965232], [153758864462445210411, 160566686763282507, -989110865885608, 79236610026846, 27803068483035, -955990812564, -3625709163513, -146324107500], [284746647381172426362, 292733768081787510, -5890293357365640, 56382868421924, -15593610819218, -919668728004, -2611083385322, 934923823672], [169075471232756479834, 193673579213599990, -3081103766591496, -68557142795832, -16964243066730, 8322733085976, 2167505559150, -4619940628320], [136598914592198921541, 601484970968450158, 2457047236276774, -68189920070865, -18884956031680, 4071166750041, 21611052939164, -3339190437804], [26423032509096627354, -743012322859895450, 3783310576330136, -399162211328, 58947902730766, 4161821384060, -9772395294026, 7072123875336], [-187130582750699520810, -1535312546454089400, 6813313747897616, 4936081690786, -52377063758680, -1247502546036, -16222725148072, -10154489099824], [260721269242905136306, 2854353144497481844, -2686692191157932, 104430300006567, -12917318388184, 10505894675352, 24066966493928, 2254485033152], [35185395949205498733, 1348140563850009900, 7110228535593162, -45404737691293, 37416881253826, -9473951443209, 8005012077310, 17480670620140], [368900841286319399815, -869669065170485942, 4511053927723938, -118492810077843, 14335097808144, -17572753208925, 20634423458628, 3082510039068], [21483609014841421327, -1946438323678306143, 7154430075377652, -55344265588592, 23034180979349, -1832620397994, 39216535037729, 1780409221940], [-182292670981625338749, -2402737781377278687, 3589493445833996, 64768902008196, -75705647964987, -21819526093458, -24910253917167, 11242899025836], [-356801314515989925164, -1040714083362263670, 4248659057494176, 71592956789698, 26888344711074, -24890634548968, -16823054617110, -23522667553440], [208665470743000410656, 3148639281210790088, 9855526247215448, 34768059670010, -48537235022848, 822948011664, -44248006073920, 6193931721824], [196939151216281679947, -1011626412784292825, 9083286395304348, 245107231215648, 90252736971399, -26957785829796, -3340008109149, 1913589900144], [-108564101648429665722, -1152635340575966729, -5638757646908642, 98700787597707, 30761891499929, 7528309608777, 26685534028121, -13355896341888], [904449203589891485112, -1428689887689605875, -13279616936840666, 45924618825281, -103552792732057, 10599508862209, -15400042174801, -13935904047864], [-683111677781998374046, -687114908748277992, -8388606612457920, -18477028199356, 69134306026984, -17205394300128, -4788181217144, -1961725228880], [32947936887552772666, 3790140580927320136, 14576110439347636, -341914200778738, 7077032910708, 10190328384510, 23118928372140, -22480787424648], [222291527791270387438, -2082613680557479253, 23644797146876710, 290235283966631, -36650026462971, 23507002886133, 22652487472645, 1857909260160], [-1095223485421978211782, -1262822894877832342, -3983897258639952, 395806449464868, -100390455696606, 18771182309124, 11054212523514, 1561121500752], [977400119524982236839, -180589793293875381, 16150051307894480, -112490626097718, 63007145734419, 35413003804392, 58543976094831, -2568224600748], [356085551535279603447, -4454721029749409373, -12209259397367904, -524651484726477, -148653817519017, 13076843081436, 24511761141171, 25583655083904], [34319028585070653784, 1430727052004723466, 32363234874850512, -494881644305966, -195751928845534, -10279142877240, -92311630413142, 6401751080624], [1464389704030484273402, 953523853885648594, -20550757628393920, -60037973627316, 44049702552370, -26560645412376, -101249392518086, -9018958789944], [1760759922183304129592, -410328045254266846, 28714413021950972, -285065223093401, 173717265928518, -19635581232936, 27137826253278, -15861252030624], [434075108091735115745, 4955973305006721776, -24016477464593254, 217187161296843, 127009225639126, 65215256532735, 47199947477506, -18253596734468], [-345624537499724984085, 2709768100646480595, 13213047548887432, 941277842753654, 366210857368627, -57019696833708, 854033450911, -2564926128428], [2020557546402997233383, -1283616746936101321, 12962269937372948, 466375856369344, -77798217895089, -65427425453424, 66645282826043, -25243883467920], [354075237926327252361, -4171667776339452657, -11476455987072628, 428699395830880, -69146254954621, 157710650094, 110686310942759, -6341747016940], [-43322347978473835827, -2649006263867520348, -26698496924586582, 614764555490979, 1935546508890, -93345129168345, -72713372865930, -6408174794292], [-1363272788464964659760, -733052868046944710, -32933772573795904, 167751791456618, 127676147982418, -63791664566552, -93488030381414, -35721594465408], [-2524225604089356735462, -8369247245998221228, 11859465011659984, -611188216267362, -95167657609068, -19178512805052, 221963188757460, 44590391387808], [2567710950395403949196, -370248786590245591, 27606391553263734, -42537521848497, -108083234550909, 106911215408421, -18967508191941, 40893519862728], [1021242243996500495248, 2620126024186271224, 40265598371520136, -1058006779765486, 408583755264192, 84621271345560, -30072672770592, -4459699352064], [-1372112523583034775682, 5832203308245225747, -114695568607054922, 251544334080843, 221545512134765, -63432245715843, -41398378181683, 9195927441552], [-833616561199431674888, 7019529016710578030, 15775250289933088, 715028595277590, 121641885018038, -61699681335960, 23502190744526, -101013647023584], [2358375083085766386287, 11480067867423102669, -15640250322050820, 851638365758484, 6565546316169, 9933543858330, 132866798906709, -78417200063772], [-2909071309957736940955, 20014894389628977725, 61125081827144560, -491256668550089, 154905497598713, -46810117953784, -79812599685427, 85263367734720], [742638147634209410654, 10772912232625818440, 76619606842421060, -1658368102660629, 126679184545756, -71960822658672, -82452463474868, -28711126497920], [-86935399961163817284, -6199983209902825312, -52737280803624112, 1292717986309104, -603475311108464, -84286661019288, -338858241711056, -28696789831392], [-3766371766082194914308, 8051165426350666818, -105778379238549120, 866991456618810, -252316362265494, 65758994080560, -168974733200910, 97150985816304], [1122328293234610686462, 6524354652370157414, -147336119488899776, -774157754429860, -36724873530586, 50791253944984, 256560332336702, 58560426534456], [-564860261518849934147, 19936804374234006040, -38610564931050830, 1784779558077671, 541264794985254, 144429315912531, 21313187454018, 132926516561964], [-6566992524448190360875, 3866623565505587520, 2980682921453026, -1183991923111779, -644591221414474, 93429258678987, 109241203759586, -68336694935676], [-129982721591356192395, 24907400731062088035, -110958603831640628, 989897438523000, 89129221827423, 221491457191314, 73180711997187, 21792239209356], [-2396307239432014534003, -9605860078325483779, -62740333887653220, -782467321371882, -724074256562523, 92213323295076, 366250350105081, -19473506285616], [1316544132746082927613, 14879707443166445566, 194872885612375126, 319771501529001, -620432405958136, -189768202523535, -315918713226124, -50941741081252], [-1804607990426597572672, 13622759584781288026, -17079307203380440, -3452628002275236, -106336207390166, -66977164352328, -19581435516782, -44828278034256], [-4046189582981897361852, 31740374956236961404, -35160976351421784, 1418328084334714, 767343776199476, 34629666776160, -40519433786428, -76445262577120], [-2319710732811657144499, -1921246067445958323, 178599697357738636, 1891762758892350, -50428702602811, -275664858885588, 305790657580793, 109721198011248], [-10593406223737106987194, -6630315472214881498, -147907918707636928, 1077514998376952, 13371863095406, 166163017904628, -387460127205130, -144725379895744], [1379139858497424469916, 30318682557342549332, 219980691601947952, -2651630346974456, -200604005578012, -4222065229816, -307354222828, -153004046904720], [-7917056654810003270255, -7576228977581304513, -142828544897448228, -2791564636528632, 1129432856631267, -97835012540730, -142115208901017, 32403820265652], [-7664806262334314599460, 3321731612785394374, 190611440102544896, 3068024698854686, 1354828211385646, 82898302270024, 137668517257510, 226626645710016], [-6627380309912828575200, 18196472558399965116, -127396012807294296, 1013036290944508, 844788366748052, -204745308920868, 402908874507380, -38069617496032], [-6556643675010785584733, -27248973908722196093, 105304164304792832, 2065473292398335, -1568582561290025, 131227756385044, 317872561703251, -238332400463232], [-15442822987151544504378, -99942627828470614, -197555492624213224, 3164438969568648, 1405669880010682, 397483421065392, 120707235953026, -21761694877824], [-10293365846998060809497, -24327894088515851376, 138524000887510870, 346433981084047, 971535628539202, 35458946619273, -85680854192346, -7140978990612], [-10852616793604196530730, 47064531351279416788, 67018476477549724, -3588458404654227, -1529098581679216, 35190712450248, 131310064157360, -39777018256096], [-7212990043471155656180, -15266680970257854319, -128181703410258170, -802682463296187, 1191298856131259, -112598631218655, -275459579668717, 371144601365832], [770151999552022498633, -15463403980876462148, 376928796842131570, -1074638305560355, 492662251476162, 155070823218051, -460476297133826, 158570443005876], [-7391690913976979322957, -28057481309553878381, -299328292264587548, 1722846447112356, 716079666939755, 148702811322840, 495883288711655, -48909952257840], [6335928565953906138561, -36644903883181587417, -100875030548578036, -4076201180428400, 183429924986027, -251027858348874, -81776281645105, 108330204699716], [377579392144281590531, 123313754384689674368, -386755377288510754, -89005124773903, -1504547644731070, 379869534415797, -75163962081178, 238721117189108], [3736080198657451589262, 2587568040803302872, -573606506851048352, 1396869951024628, 2053743186539720, 124760637846000, 447784049632808, 215795277364784], [5348463159336931776662, -18836147485822963849, -475275050320344834, -4261899468887721, -2104970874214263, -242467031062647, 282352812610665, 431483977777680], [-17685645150889136095620, 37145927238474590183, 554261736404634874, 3572464422541103, 713336210321261, -249132999563249, -260903085559435, -416913495207480], [5352518229945832153758, 513947086356782136, 90572384339960048, 4507378772621488, -618102725963848, -193794043603536, 1280671246581464, -91870650326416], [-8672179370189206718852, -28880193174690026324, 127759852987270976, -7075212415889416, 2427276524130508, 898410231091072, -432445367149316, -345079841119920], [1841430685358832046642, 77107133225333914744, -15241416078148604, 8735495422582074, 2775565097893892, -622114749459930, -261919738518340, -217741951980088], [22570688224708984733691, -43825671661092220515, -527040005205476636, -7100197209268568, -802879984370071, 608717447473554, -239989107963979, 124393954566764], [-564199530942284115804, 30948535522419831526, -385855635707056264, 3015820094957560, -3062095042494986, -73906562486128, -1929631341480338, 131227554043728], [-6058850752272787917063, -22465350890817815085, 425560635488235572, 6198813753253324, -3043766678041897, -1429943950549674, -465218540779381, 17703978254060], [-9509758141872597863559, -30505492598935190931, -480943644908719968, -5153202982405005, -2008474013046663, 788244549889416, 1533139287227469, 629166391199712], [10407359295602283707322, 95325392880180462084, -507117165328818444, -4757865399164361, 5239632231732984, -283014583123464, 184760718343800, -196201200166752], [17248146973496113658002, 33576358715693675244, 689750014480119552, 4455902197734484, -1514745442213492, -567216245712024, 1087711600663004, -363105545797936], [-6865669162678600676926, -525248814362403028, -417892181131391548, 6167236168653211, 278268017719536, -499917433496760, 1923110216107920, -109565192868480], [-16619286598526969878666, -150610377967803578857, -140908032249422882, -6718363359181355, 695667651197849, -1104049273163851, -80672193263239, -85922861898240], [25859348089208648207195, -89858797603047901726, -272353413749434198, 2555380615601647, -5684298703348200, 425376512803647, -1705362617669460, 28983782371620], [-18014610354763772373715, 104641545670485440154, -451216618507732162, -2204675483572405, 628997528899220, -761210756872947, 405289128243696, -947440505946348], [13112399716968738278221, 111743215030046461317, -286508894559435268, 12529984120159536, 3486464832865741, 616993716717840, 1541483796700561, 804782226637584], [-2196984711432625487931, 12620589307067025869, 628341695945900896, -8073432360009823, 1464477766653977, -787214257786532, 1643692429984925, -859003875226368], [4440033540790319835687, -96966795024936695004, 667210324657841454, 4042746161708385, 6218908049548470, 344916490444461, -2754006461727990, -377315211859836], [22299491210323984048474, 15818553891315454582, 222241639004608600, -14416713504529030, 2893170372695958, -94211288100540, -432059631630594, 966501603553440], [-14009685794292172613190, -8772562303918290120, 1036394251573276432, -7509703028243300, -2909625331167928, -615034325782656, -1222001437255192, 945972016559264], [-29867871077455925219924, -68018755019620650886, 1537322378561382916, -16385890189124154, -806227326935818, -250711478360970, 821873848733078, 528356929271904], [-19878406912032556190118, -243521446492148533080, -92027925970646508, -19782712384252310, -4334356171284124, 2374869385438062, 4293738963871676, -88975322521816], [-1828095326403539046738, -63220165983274310582, 2079773347132509592, 6776008932152412, 1086764729767898, 1195681287548328, 1902123043348418, 81363467692224], [-34999115165672259441597, -69840872149875274203, -873178486978296652, 37809494635829768, -6363898099267463, 428435902712502, -762425161053227, 373736742466084], [33551847340217675443515, -156993612722618025257, 66150498062079872, 6571323986975677, -665568959877893, -234518513885680, 1635962438746327, 9398243448576], [30854088448862187820220, 77288139511635482808, 688334713322234560, 37829886642029364, 3935409064875608, 2375275429868424, 1821256480170776, 261953082604800], [-13248312943875621244215, 300801778143381055642, 499172573531308054, -12380014323928449, -7348152054168004, -1023703256758863, -4208129364064600, -1273057961543388], [11089269823210826129334, 38618478696444305304, 294530474085220160, -17725216845907824, 6860708720214648, 2411235659371536, 3760574854734744, -1761555356344704], [-49161671589863283220715, 50844594781480884658, 1524650503011322126, 7210210742611029, 877435809086756, -155971478057403, 3715390030498160, 258115874954780], [-17076159906551458324199, 4566903146172832030, -447919493870607794, -15668951000141077, -765510361865400, -1020295009210155, -1660327484007788, 2720274549172740], [-47132580385148512206653, -73623460991272031085, -2388118247465232092, 2302864034446828, -3877374827319125, 222680038578408, -3355409747308569, 875825690901840], [17196624401499314157597, 265572720270618574213, -845161464318813424, -43133762677433711, -766780790705471, -534513830682076, -2664012197059259, -633693904702560], [-23455330026102030436657, 147744188038723310361, 1456072098053931636, 8002428684392, -512191786587131, -1315691051503374, -343637379179903, 2514451820974060], [-4301464237103874755171, 286448796086976093142, 869068240152083254, 19898715856100585, 16750844175799680, -1763125439654943, -1601447220703668, 1378641736742460], [7790674538229936843366, 353584449220150863384, -677693884592702384, -1352834316801504, -10672192101315816, -38164778705232, 292425833868984, -711842406358896], [11092427192609073460700, 213526130678311442719, -3228426746551114870, 30081268687926819, -9591632391979547, 383906667999831, -2936090214465491, 469973726281944], [95830450409738370771572, 241555045428161643627, -267087113257989166, 3523534149133277, 5560832290462649, 2449337334326847, 8674521062432481, -258731364172824], [-39436986957440499964523, 729348349002187851207, 869170064756994036, -21110982515316948, 526194428681091, 3121020457909218, 2773371218827863, -235059760593708], [-14726806766868793211690, 432028914962939425206, 862143958799652608, -13839468693024636, -16258525333616978, -1614016419839052, -750583550026442, 274541745740976], [70677627202875819448192, 271327965985059980554, 434543403796911800, 3232770378167456, 5555424021715402, 877294049993752, 8360619371825458, 651992079029904], [-5213507424892968232123, 239848710216032757897, 2473233653378829120, 38965818532568390, 182895832718929, 1618496035581168, 2894452354210789, -2225414003816900], [112620980783022617339712, -4829848904010251862, 152472252507967692, -16274440462037694, -9901618840306866, -2019551875505190, 1805347079855646, -4208276197163136], [-80584067211881256344489, 217111606977385237963, -2265561020165568016, -8072556359779807, -12578122864927889, -2582549818312616, 2426084259060283, -2130245270393760], [42955344390939065559892, -516227624332224050678, 2133319948524312916, -73820102518718863, -22512922018568922, -1734334095897432, -1566016680002178, 507413111935488], [123209669259621219519304, 91676385176141008324, 2406869112027367600, -77728171208699068, 10152855625733892, -4498530773072856, -6793599098370380, -1035027370077408], [-15882581817022456785994, -8020222652820712156, -1098825753870933068, -25103059105957550, 18847253022211472, -1649865063620650, -5777725196545480, 854835598923048], [115567736364013230110862, 603734648811687804648, 997590229255234448, -37119673748108280, 11146647726754248, -2432242287331056, -8880572988037464, -807424958993424], [93775181644293391542088, -131257067636269646330, -2062127825360431196, -35736136866256927, -7740908924421822, 6278683927729896, 5685404298130506, 2400222897497856], [92785179612673300651906, 504042321131618369604, -4185240643695532488, -35610040780799618, 1321048229099676, -3758930850743560, -5838169082377620, -576456593121648], [7323098757547331833673, -497130591054999811239, -2864169570820141364, -50714448474533448, -12173537069202079, 7896024756969648, -2342075305566667, 2142666798458256], [259408515927759445431326, 359731875043198067201, -3651890846171223942, -16909627805398899, 608248865179863, 959471820485883, -6099705144128601, -3187955294332416], [150596270204238215973812, -486826409282608135386, -1896500029802589696, -30710586160297126, 16435225703796958, 5843355213780216, 1640712281922262, 2362705584853840], [166281895722986574933771, 110338906446779417061, 3492278864411092084, -16516849216125768, 17077688973653217, 4145940572392026, 6842676249822381, 424540832509356], [38186226084357908424990, -507494698156624294196, -2393688972882710872, 86587477015247566, -5082858428861036, 4481977077835136, 13425679538384548, 1979716337986608], [-170414979677324491651260, -575590291583693811882, -1804869033470125428, 23034281767359539, 28100340149323738, -2656917598707168, -13009774141776158, -8897465329638656], [-28581133475938452557762, 413007439373200834894, -2919032039193866640, 87560352327448368, 42417353754540630, 845002381477428, 1109708589323646, -2062832938110864], [-166478553962848755808458, 710741465360336438160, -7545534837352934912, 70498640156399980, -10343087234272096, -329193728102736, -6995545713937312, -3535462954841584], [284942422364630722849913, -378834203260696523386, 650615290542645726, -31205004411814101, 50801687359782144, 10683870134413581, 15059380636151052, -308655320961564], [-50745242563894634802718, -1218787962744353161814, -3711431717846188192, -139776805595220564, 6510991523603722, -2188661989900344, -11864216287010318, -1736223343967736], [21741137379496580832560, -686334455515113436774, 5575917592323910172, 66014488449505419, -43915882541858114, 7955171625832464, -5365713245265962, -4378574440457888], [-234394135152911181666450, -297710256407592183647, 2978237127272779418, 158909179364046307, -19157212596303305, 4197461393910335, 17825420025101383, 4265651042482752], [45087252700270383975413, -1169583546534214345930, 5221282556377506758, -40527342583468207, -72489261600983248, -3045172768911543, -9237081199151524, -5920120603303684], [262528175310350995291227, 504785871493523092365, 5392494105527871988, -488676065605544, 7948486539567569, -4833549259428690, -14628829879037203, 149326992255668], [-104600169468647116091197, 144690187088169436473, -3102790331799410052, -67979256007258852, -64476837524963027, -7427527098609834, 1415231584023481, -10228060113552788], [-259077385941425311349518, -1273933505150740839660, 2228008634147450400, 30934158451843148, -29820624413309052, 1103846737241632, -9746323212276780, 9934759785799584], [-101405856289290298764800, -40757868896969973008, 4093911213654225064, 44938875457620762, 27739146847712216, -14206286978041800, -7720504073278120, 9005480106328544], [94735787446732474375309, 131966986120489280257, -3440527613003164668, -71186576337590454, 12877165709028897, -4210521963165792, -68383086930507, -4416251090650128], [153730474719647311947270, -916523429310116349708, 4328562762728583904, 56955274100259370, -45848245901244892, 9153741746214612, 7680398454544484, -3008698780229824], [-240960921622887554939466, 1080577072431549646729, 664176652948993498, 10017188637507201, -5844863296103761, -4463842655493093, -9180582183883009, 12605424663269520], [-204923519626343053856584, 1637506465475956799339, 686650305404785354, 12400516136345755, -17141069825329423, -1482404953502617, -4853038919629591, 1585012092515784], [-159944161892522220276290, 106737563274356884724, -9427098275109296540, -165646916383580046, -46239496950281488, 1903096363802382, 1191575722686008, -1479608921297592], [-434805124394825475408382, -1142806599300614879758, 3656651007471553904, 156681461733465256, 10329737594575722, -4347964829600580, 24717028232047106, 8686976079279024], [257496409798734509033559, -1596580913688817708797, -218690870646062176, 84616993057862106, -32353586705114613, -26251728359043240, -13123013752023993, -2241318495464604], [-652351026516552727304230, -1619405391226609113484, 544492117250982452, -170433689482436065, 1729655082338792, -7447767028743576, -30799901687316760, -5671926479720416], [304499017946006570243778, 653463360888918842184, -1152731026431740720, 18583351268430268, -16874239872844792, -4482895417296264, -41554438429826872, 1517420937370448], [27741628509363424381487, 2926813047199865739662, -2645138905715066134, 222089447279969953, -398146537176852, 15618587474470479, -26162264960755936, -91437041927556], [-396239000920365746198166, 314919168774961375136, 12137622607392818308, 33290300274430994, -27652151180096356, 2936315584411726, 15072255038733524, -5710260893561064], [-602824572972456959887128, -1502915821837292377962, -2621683677687864348, 115922771735023849, -390561127982350, 13544593523570472, 4916028088176314, -6186279753816928], [-441690467387413234936780, 480028995945251873307, -4421248752851331102, -70408022955669277, 54642399096710169, 14758555911555403, 11481588865014561, -4205891431023192], [403417359057472087140493, -83514120692282393859, -4433812811065389624, -214605568161411302, -52104737237833267, -4394443443608844, -5507243179540927, 1061848105039436], [42875189017892522592745, 80334389061780508881, 16504159711845604892, 101620012132641378, -78574726249659575, 5515720527836820, 16518872265661741, -14806500588504720], [167961089136896786775835, -1120310054019506664410, 17630837183454475714, -313927620930710453, 75979721778408868, 13632115862882307, 8819294826862360, -1499044812101276], [-1021152968530640115007430, -1737499104504665446360, -10689838426782847328, 114989998965439152, 68758512934786568, -5448468594360720, -8538383639244184, 4982507614751328], [-74954538459470048567337, 1975695628089064852883, 1315688196795585596, -300416834394959598, -40669641835699517, -2302303851160080, 8469937037907007, -11142986506834320], [-224621241253511810764710, -1200638880220552679352, -23227500913637587712, 147705020686425866, 59601141999545800, -2077965600733476, 23878705477788472, -4392861622220672], [39902300083328545594336, -1362859118122511927241, 11636813407635065618, 115892414133530121, -65378659659390539, -33276977199970593, -46089708135152339, -11051190941286456], [-1131955752200992106689688, -3842199961091302241443, 9959421168681220678, -34682727583712655, 2984275313163287, -10563171769833615, -14405236961427745, -3097562602584312], [214014693325345427559936, -1154720299299595506978, 2242955106500267216, -73127184654244486, -104452374998610266, 22658054824144656, 45812028163998046, -6249582364331024], [-273084315205932057279718, -2339790856915859077234, -7313717040835791784, 188881339701243106, -35728148687294322, -7432176284293212, 6323771382146262, -5592961942640928], [29855120597898349027220, 1434378016771370328111, 9217910297149124650, 391513617946821957, 101709086686472309, 24332342851583619, -7851093538681123, 5981997856498200], [-272794238093900409239922, -3371211808216120988448, 2566425061236815148, -56854481760379518, -103136650067323788, -40767425694555102, -42400210975056420, 15950304094057608], [-42199964222089597345226, 1702328489561191129588, 15107368450676294860, 386649839695183737, 91201092183720128, 21558597883371528, -4405222461277408, -8248477099345216], [-428000354784735024677654, -724071680916025979042, 26160523825350685320, -90745848244813140, -70767567631340658, 828793234991880, 483025720886406, 5973992647996032], [236551304677594702685736, -2391039133874821516710, 18467508251361887632, -15439922312207330, 85274692961517074, -14776855376671584, -41536060150438150, 30167524757747984], [142204266045485026382019, -2614559136662641175322, -24138218543153459454, 90507559569340531, -45286353897341788, -825386021973165, 46586776508594264, 28234842041870756], [-217412869982519861283465, -730456635523780912768, -10471266355898269450, 54670098160264311, -149150393872889678, -22539236617424103, 41032859215859350, -5488449633675252], [-408331065516330708170021, 3330451519216368320115, -16504097485369176024, 298994073831430366, 40649004942070451, 40909098990624084, 56310381003812639, -4370474385122284], [-555945468370065139755499, 3522213337091919952981, 26772922465495146176, -39853648109524323, -43873309382618015, -3690552603080508, -69849260749397531, -9322722046219968], [-315478268749701438092824, 5701553140880908558646, -1092778238793835880, 196504592213436400, -80853336230191738, -42600040101208480, -57393134360534146, -6668454950542800], [403490636426253620729648, -1088589682057242725704, -6986756981433929320, -465303729023106722, -87413314867349808, 13804522842570264, -29241251215222224, -12819773824611456], [819529159441971653893034, 4829882831498858311631, -13579127323518022138, -9342841956878729, -190707608095112103, -34610249860266099, 10678420238289929, 6359895497872800], [-292816758868819023498522, -3009001132000705676784, -17891767733452858864, -108385575894703568, 58435427215879760, 31641626814122160, 69011131814145488, -4134311825091088], [-623228582089952373014508, 2040655190237439076752, -31904651835912381312, 69048201635303988, -123395865566741424, -1892628839684520, -41988541238412624, 6597285052322880], [1128171177272923219146766, 2655352927394306304064, 7722741649856684908, 141709816373578230, -5757818844298204, 12934159592734626, 39997442018932076, 7134736394126744], [688238049690011806429407, 5143084924499890354761, -8667285074123690636, 489253552528389032, -31895430537637307, -1560789115444134, -28208845943793119, 34861724522963068], [-116915215787515302075362, 7078790179228492246060, -2590845996038017388, -416103717645914534, -13474860597707576, 13484807580919710, 46347757902419824, 8901937022451160], [-1173857286121138807502076, 3840833188639197487026, -23586428925398706972, -137051740736392255, 57744249182579710, 19247237688860400, -18867966212374634, 22686109373946304], [-1235246207063350941854790, -2328302919112017868486, 2630621624162545856, -268790638645673820, -127725465118185470, 30000600442799580, -60618448887562886, -4145402988110448], [-82871026989951875261742, -2453106343989256302216, -9234393552335138192, -41629195949359716, 93646685564242200, -39631363463989944, -131131036758816936, -23213434656928176], [952107858063017291759142, 5346021922081781771568, 30092519920905871760, 154688616705230096, -37936499021566736, 3948354425513520, -54889235896041104, -11623355303560208], [-1053676174912735165129742, 9891680417064751549863, 11429500430651124534, -129767830197949139, -79994059998364959, -33485529112093735, -223651805665839, 12146582334524256], [-527967322857790728648709, 4063106440771806657551, 1127529746416025996, -217724060261058230, -337196524634141889, -15123845740758384, -15318871315788949, 25403099810635728], [955765347146186960963541, 3340567606599752936043, 24707214059511338540, 641204093606896264, 314456807434625087, 6934978641758670, 2199546538019411, -59404249624301308], [-1042973889467619731577585, -5400613729782242996725, -9825164390702178196, 333095953203955836, -85766280946032341, 3804003156247860, 80424365678862007, -15252460975688976], [-139264166764596463689258, 9038241376363549673256, 24946542124565352848, -754627236725667024, -176674101421803192, 37132480310369184, 10205639873326440, -11508819550231248], [-1070321139825715049174810, 7439688433428124620478, -9226422550957377488, -412182820564481572, -23790616936283082, -8620244337581676, 95983299467175390, 15568088900200224], [214357050373266097658672, 7301016502479099334294, -16904822879369805964, 607479550785403590, -65998917205485566, -11118919542567618, -13733537815903886, 28029239247622032], [1913882426336118274612998, 8667079875066948293670, 22398370686761670288, -308633426805061180, 17770442418960694, 22866813911793792, 10327897826963662, -21483635314751048], [1466873623553755367579950, 4867114450784329293523, 8153941859961144022, 232892369558835095, -198968513624965155, 47343893567580957, -46679097660288803, 48704842000113696], [1026383532437217838353609, 2275607015669218609167, 4137363268429134124, -275991272169959696, -243272668289011501, -11188018551521610, -38960639431289257, -17741838327211900], [391701693837221708705264, -9894132034583256075674, 10297979958911188664, -63601929171103284, 133032103536210070, 46315833796410840, -22186250738186642, 10058406795073008], [-1114956634616435700647991, 550360118544874973857, 7855707616663464800, 177517831768358029, -18543884716140995, 29457374396175116, 22168671908704465, 93234644935717536], [-2520518858712027886807020, -2954513942002884160480, 40744666515350559392, -199423206872435100, 375281063879467360, 59527071108531480, -98887319552991488, 1121157591501024], [496403037911323367448623, 15398847564961932112070, -38525661627427010278, -902487631291477607, -86568168796440972, 16896970524709815, 22778165141730152, 37155295528780284], [-1428242934429207065632214, -1395004616255934386231, -48199134028624297726, 657952555576399943, 164345884576542199, 193483319241931, 140918051273014231, -22590799841821104], [863429937632639559388087, 7681252242627990173278, 32059390635492233818, -74080268151918833, -462661075521356924, -21363363634087545, 10778097815596840, 62656960271864020], [1029585970134740570795341, -1131902898457855741143, -38024795448673373712, -147167822058822209, -188550645716541867, -76783538196744400, 16142073780749241, 49760562022283808], [2688175703688999853226859, -6125044932390759269235, -2179460907613675900, 196297279429359408, -183265859357020311, 83499823454822154, 11770375616244309, -23000464981796388], [1336030220578966416823496, -19828182069966332529355, 8205365184019705670, 804650028304971643, 112062028724125791, -72646539824029755, -156548572652862745, -59251023652147272], [-271915304238687538805692, 11122104944242747994887, -82864163230888611862, -1249809826280636469, -85901304020084435, -73304011596544233, 56116033647472021, 5054191114683384], [-199916934354905570965366, -11932342648890144075982, -23029493804088696640, 139825236701334040, -284842607838512598, -34376765757488820, -167545600265025918, -39821228517367584], [3754307037144265433354612, 209189722366742522570, 17618211998877350036, 380338652522915190, 153613234134646822, 87626391314243574, -24164471769734234, 55842861317643568], [1077329489922507427001654, -11849187929400049412241, -27719569970118832802, -863906239249785813, -138936499181390143, -43422799606227327, -18435866604849535, 2864091544612560], [-1618529760823138800155345, 6917400065850718793733, -62307620928019335780, -71729960918768796, -360717461261442807, -40613924978498322, -32674005636853659, 60805794319107852], [-1557422523294126345761330, 9935029848541835423706, 14699123119699278392, -43553444358821256, -526643978075018390, -25696612856890896, -254094636325315982, -3622753171084896], [-1211618143432394050424451, 12573441740703407224773, 25488274309132755320, -1387276843738492934, -204270155348508811, 4639605071986548, -159295572498672055, -15573517576332964], [2269300270909292474550738, -3023715300983672454786, 91130054585267813688, -127548421804521424, -567561788440500890, -70162371269899620, -72261899385481778, -27901862609890808], [1858444017313486539537376, -1801176665130850615064, 94931766170813233096, 340054620425809724, -527800172255751168, 32364418695827196, -252392002032737840, 32594098176865584], [1803594996528639751615980, 16768411609537258331982, -56220762938182971344, -316133752284716534, -214177567784601322, 63430607427264144, 106966847868235406, -37390693046366896], [-395875615074786520104798, 4802614958652241481800, 59431060107157157732, 85404319527574066, 444982339579177732, 104533817428039502, 105453895675758940, 309233590626456], [4179998237164658837975781, 7281773009825841870606, -10643318845732962618, -752605510896115639, 773623829874497896, -5448284080892727, -320177307103859468, -7425026216242820], [-3407952987907764354012543, -21438063989279475768959, -26158950905286222356, 1930233330488822598, 125846391756699113, -65755835570098956, 57259399797366605, 110500770166607376], [641203080942221514819913, -3348172732727303464519, -90389361306922678736, 2701336185613503939, 269799552337162853, -22145463194722680, 117239641244797865, -13048415540973216], [-2246897239174211660290826, -10136779455418737861144, -4447847909060890008, -288078726475474574, 135557218121311968, -59636952108364624, -420329465563442016, -97749160568894448], [-211014287495438449178566, 12128184090995627885954, -159272129267346584848, 879658921722564520, 156942237800601642, -71725835926276236, 108297839634002274, -10235083658100576], [2849361705560495729431785, 8621041789080932344649, -67121322064790160532, 923351524294638948, 134290712889728593, 16977369061017048, 172995553300475077, 5233049711277552], [-1750586062932789820234710, -17306235110284655141820, -24538130595316129952, 984784643420344512, 323329975016603556, 173942279448378480, 265287017318701620, 81920778809084112], [368396198893316644024142, -3195331789535018543355, 55369264364194250418, -282098964575056897, -598711485280037181, -56547132595274957, -463993373051348109, -26481048492906144], [-3567240309260064402276430, -2942446437746401723656, 11566266912250755684, -55503906297630694, -149192317577228172, 42240587263936030, 1684735404950028, 208513604360790936], [5381406146484941193817696, 13185302352602306826838, -23991579932605070732, -1602129627908472438, 957733108477784546, -10474749337242, -248204318155048270, -68681293770064144], [-2813508335157582948499108, -3075746914060271761414, -11930329020735430952, -1666405674568660796, -177805096011249958, 32265447395976032, -104558220565717534, 112077471611664], [-674487528730101551314755, -26594674387800377643555, 144116310070374061544, -1812998880523117374, -191762608830351411, 169465527540732564, 20051188306105281, 79162064029342284], [2914697696830111443447316, -9288669621318096590294, -68718496386109747724, 1727050911690971214, -844748447139842746, 11207077606694022, 63169776016171910, 3742777143908240], [2053303159327613528401407, -18803263716296249169285, 106014456368568726912, -1761211456223083665, 383814470011956975, 118567953658184388, 478270071200853387, -10176856125724800], [-328789527918900445595856, 2756958155301842542842, 90850043965324025484, -960090600109306177, -472237564494874322, -103502289024763008, -225136826372392250, -58098017167170752], [5155040964818499514001589, -22805179166033677737680, 33071730482203698658, -371396091897785475, 594662280230101190, 236058906277447899, 461209477605210098, -81515122469629596], [1226090732873960177484914, -4328817275158977472020, 15405947722895193504, -270487043215199412, -101738487021223908, -196771177460677824, 99214020721563468, -179775755790583872], [-2410339850024127903651933, 10488756982155828989901, 42266909115447185284, 170156563725950648, 736300145913211297, 91200214053762822, -72008711688717539, 31919168533925428], [-7950133836258025780687934, 7718777604112625459002, -46674122225168681360, 757433218883049536, -824980129796512542, -93816559231887420, 1945024268729658, -28452994251442176], [-1272994132527386026074485, -5538418034593353178205, 48846827882593771300, 1788343117392172232, 465303264202928571, -75145356560837040, 105215517963079831, -211017023922718512], [7391733372006725699274266, -9632076587940406911253, 50201147690022675774, 1170995940766745607, -533257415901635235, -81321302125787463, -153919308399495219, 55870740460161216], [2911257464946926270918024, 2579180800299754498938, -134776756189413372576, -210979759447185238, -1150791544548585278, -15999569670916224, -506523157688090006, -139163445176068208], [6302448385495982578080154, 28843275207801700544029, 170702340912423396586, -2694382556666988715, -30067774820316813, 16479594582901275, -278098451081503757, -126404772568233408], [10914118759649230231679989, -3719558901895705582605, 113270717764654096764, -1156287227497407392, -291912622382762041, -196082464802445234, -126378650387883973, 11409182426333204], [-4160814723125442460345270, -9531560550098156572642, 171606019757731257272, 1264544714208160312, 186268022325603006, 105833356856674872, -113210260200047050, 3631367159205120], [1439319058748811121975769, -9142902727648224488289, -222742661575687528356, 135698705702728032, 628416403748966427, 26302464664058322, 411523392060704175, -19160762895322644], [702586927654725535082216, -8693160330295754268312, 87639963145278047960, 422510807119291316, 68194157644032368, 319746008745817812, -115885078837453920, 155539399040211600], [1967561808262672896736974, 1958337280552198269408, -89225001353127470240, -4218399889080966328, -3461195393510864, -149657229155639592, -400359321678701552, -100706512185329552], [4270437886398157019268931, 23970944690383072826286, 175278650934997299986, -1902621343946953923, 195491765530800964, -270380746372475589, 126676952558193256, 169859488562925516], [3369103998839033187174086, 6976755395949648301992, 38762306106767964816, -2073011271677177170, -1098414623377007384, -138162499787703996, 307490152272290104, 294508010819817712], [-3560259809531805967308684, -3491331402063864969606, -125434677236845276572, -5772079482997187795, -1094029811137008058, 261179671565724216, -357806392446769570, 131568556488619424], [8455504543431833029906417, 18367237497972293532322, -110601900443468710250, 1681036182704548873, 67558549511573548, -252774701761896303, -22376212461160088, -118311096297601172], [1511031644982881717402149, -62640242597941266952232, -175387455427541416686, -2962551774863089755, 665397615821515614, -112657700827917837, -352943479209073014, 10802365693306308], [5639946184770822486851873, 31686840098991154947989, 28422732965120989072, 929759213404653277, -171242917522514671, -135050967973256884, -436321298435954635, -62374071022143264], [96093921080585448848217, 22474218494302918374855, 992222516822355260, 1429028915907438640, -527171388756477877, 83673030716446662, 479200369677682031, -121440964116329260], [5384188589129772225762980, -11914157576906762429413, 173641164970144539890, 1227204004939573489, 660047411468059065, 258918828380397087, 599074291597936001, 40569262833435480], [-9666185392770008004387094, 12239425948828066777573, 28181177216564329226, -213256231818281385, -955065882233412293, -105082430647861497, -213163222850819333, -328709681438992416], [2082880693627607855412408, -8703561856703596055070, -137954707183946029696, -178381076142239806, -734418862727422262, 228235394116142784, -1068764268129404270, -3834730666550096], [-4738653691343476588032916, 22539725980844790145160, 92168960187418623968, 3735176466669989880, 1032160666751066344, -312133700004563040, 72593870096775304, -82551408226512224], [1728440935224268577234434, 43634302237871684473104, -37503096118395798060, 6367721207334905650, 458075913331797180, 107187887989877942, -74711036064561516, -85204826966482632], [850772335282391844332144, -13628914970944127980971, 16788486206441388454, 1927961847286970307, 1029215059073522447, 183347183584520637, -357867195254507401, -39097701535827096], [-7878432003358799059030051, 38383656623183659962411, 194577208882886887692, -1446123643298310400, 2295231782823563047, 281727681670314306, 135609635995953451, -111380836562518676], [3159414414140475583276020, 36571884775475287317516, 152765428786145591568, 2607425743252638892, 440017503734048780, -164555735894022504, 333021697034706428, -13772617641225376], [1848178935398885557431291, 57064600423141695585695, -1462653334738121888, 950936791979329643, 1644292718579919011, -213607763895834476, 307703564169957647, 40859704137157056], [-5321528936547744913956530, -19048074251769601176380, -133833252255595805828, 2077812492558875617, -256178273837471264, 282919629702263376, -298013159338781792, 97459708261281568], [-1063932656735274082423994, 4721365364504952042396, -81712814261420836176, -8348498425886513924, -214774740587214196, 739648372723150896, 99543793095349436, -101061992021635408], [7274117639320582100295471, -6283087423474059422090, 133600908555727975642, 1023214221567589809, -291315944254702300, 179541550874930055, -424704185723204008, -76139480408260356], [7694376869173723460854840, 8978728403045079675912, 423020475597753399840, 7253901201097764136, 442101298354553928, 157532218392040880, -124749653752162392, -81976225512693312], [-677833471696675561309102, -8626423770656721675551, -128917495282858763038, -6451764038528351217, 879988968719263759, -443297498929455909, -190517236324767089, 81421059841560144], [7208236556730396779582527, 25300415622631109059252, -3945211068314120546, 304311813752755163, -679736211679429506, 15613206951496197, -47137682060535326, 331971131481156684], [-8504877127575202485566709, -1750720650987527140157, -155201701382881664636, 739857587841186606, 869962720192163867, 62054069496018900, 158658773114711399, -243649315180128816], [560774225388895784427095, -26710501588575396712852, 128371801827485922158, 4372720355299046441, -682114496538460930, 428035146591680349, 447681346511981234, 182519491723362596], [13980274472873236416191480, -38719725348036190078738, 80804923422453161992, -5975331024864324800, -2257048463295038866, 464279685992202824, 385134339174845414, 24573068560960848], [-3539006012565243309807829, -6707146803363422424741, 82904849717730171764, 4786460138336794856, -1486735913780244733, -382984760053680984, -109825828277013345, -256833611244322704], [-9357451300477102512550400, 615101089214649205891, 503717111567075892266, 64265239643302283, -386144564330941175, 70504764080266087, 254138981422223713, -72997319945356344], [-3415115073010869795235722, 1143091516644897906090, -375190570902328198104, -5044611680418679558, -311968851403271798, -431426333112912204, 206919482173762882, -477777776408094944], [9078363864402344673142282, -87658374814598776903802, -190336756394411214632, 6142516361515358492, -1306927668530996130, -30055586877880740, -987355685922526074, 24883341643728888], [125819081844647405959668, 24150108273410598036299, 19749396240232935842, -6751089923895808263, 1550003843538976489, 21303217666664607, 192324185318135857, -110412595347903000], [-15320278088173509915614640, -93467015995490037720186, 176256109952336838756, 3567549970721241537, 1046218969486399842, 87256088566741368, 1033157381812472106, 244922305493573856], [-1918661898789563198309638, 34565027182551412312428, -15517306266058871712, 2032296158684654838, 2582565330542954220, 161056651710912804, 1691333221360865292, 146077891228226736], [-6243855678549598142770536, 26445456417954063718915, -106920405399703073830, 713074887544834171, 1735889239902037369, 155556702115561967, -1198845807225200783, 256928596507842696], [-12359776107798382473939723, 33369440434534748977755, -60085709579607789476, 6694291440329145672, -430094548829693433, -522450508650551910, -39714199791835989, -195735213469708788], [-6384363914055126780112399, 20242541298917754504305, -593695417188245556132, 46560445661976480, 1141351503044845257, 78935377016498904, 382976208654453405, -373112086056818256], [9259726766618145718874687, 9652777228677159144039, 278540948950477372320, -1280430111826415563, 167435230488332619, -15684500498530400, -1327181016933285081, -75351864692009376], [-10232191824799148593593561, -27741830988750012274515, 559756469272950446012, -332466726545119140, 194769870018289809, -3649232832601842, -316177709427280947, -237739195848170388], [-10851660513946786348077357, -39049431369089231810550, 327197348925454570698, -475234851949233097, 644036892882444064, -466593616866505281, -1213577536253789612, -204240258291545468], [-13056948680870625364199734, -3807030774373619004499, -108114149620904700326, 1195328591275858303, 3434975802744812243, 1389907325689242671, 566246132839241939, 87268494362822784], [16040545239506257418459420, 86093055571299690794704, 57160219717884785528, -8280375628354176780, 771230781354658648, 336544645966249140, 298543748021300584, 293681232493579152], [6767566101505777023495648, -20353027108147113357684, -594771810537844723896, 3668117545928077836, 373791886180186980, -331402730313721572, 941548085526792900, 289807237890133824], [1933292018303599768811792, 8974021557290495948914, -13053242255730261088, -9928307624432554482, -1661768893931376086, -448802193249819408, 344570247550454578, -10135642512611232], [11742708336355247666065790, -60013286168484950922202, 237290852350483159328, 355660245762412148, 1905828442569356582, 250613456807073192, -252560717428436194, -248058739120256872], [6691714733779562972512073, -64145102134189070534971, 392116008286465431232, 4484296420711281319, 183075409910695121, -11726582885859040, -520415474361470683, -675793775106894240], [18080633263661235414925951, -15993414876951372985380, -521849462784278578354, 529872151837588155, -2134389823677346634, -523209073136925507, -1526671250037438950, -355528450896087348], [5117046694781514341723622, -157473664767990447323220, -236814033628245820404, -8190312574458836243, -189719288252085448, -645693733176976416, -633433930600988392, 797478025546509920], [1867090510610275298787995, -41113521698358521896434, 847472210256072282850, 11059436222056620909, -867145760011771372, 791437255389964131, 810155251034305688, 91737410566130028], [-20160796073905225161005897, 17126408856463168442733, -611938819820513875956, -4582892823102131516, -386355116428134535, -448112829640866894, -891965119303133659, -584631004518262492], [-28427025376553853961693421, 108822512832853203345675, 272072365955308903684, 17512659425775650626, -1244433937874207261, 246949002294170508, -572837447691954321, -150063481856720592], [-6123952766491826936387151, -82657875795660219092829, 131008790393017978292, 52609754625915692, 3574917765033982639, 617695945587616842, 445852822461943507, 515247155726234836], [-12822679836496380293489483, 3024411333108844101808, -273847563691008515774, -2674495099889831625, 485156980472194478, -127892839157452677, -1176822587940158902, -306815987027453524], [1973634570586282093627920, -100453311662937647473020, 263954198778904018896, -2293294300931170728, -1289380423363653660, -631571200706557296, 491185578790499700, -879327292937549856], [-28099555446049552384064099, -82095467408311325030327, 146211788613413104948, -4526695034895622282, -668555567644507815, 611337847475333136, 1326332266423003405, -531009210223864944], [-15119531002583007128242490, 118807711799603934079620, -273451501477290499008, 15467420638740792760, 2091213592936321700, -484324324355905344, -527168627607824908, -29228473481873872], [6154596183119546018806430, -2520421857267688626331, -11805496655546314014, 18579761422398390825, 2061150841125245859, -212711778283178817, -351409944278683245, -315534102593099760], [29561591489315319997091616, -76860281777221958744829, 101664670228826685546, 3931723812617366751, -2316553293092928231, -571688347329727353, -400491627243918159, 218684144561456664], [-22793271939130465035176536, -83405032159342488874456, 835358667144075977144, -3544625826670956050, -2116594797710481888, 571028138128324872, 2206719405130907136, 161118409966839552], [37842150234679750036638768, -20019614516728183107164, -680478105033081181096, 4481961481513634164, 1382195165546363980, -537696268781725180, -329293949171885972, 495943730160526944], [-22714701953376171408979360, -11429199641327164869544, 929108153284069268720, -6383046421110596132, 1405824568091552472, -106409432067484104, 976720261936183224, 307918235469239664], [30025488032595847595153157, 3644241179992624888143, 863080584554042642212, -7533463107327936500, 495885181240706699, 616745902418637426, 951683128167978047, 294273967028779652], [18230508128988130894742696, -147177519809600830986642, -824141085667812864960, 14002662274885440050, 3451562852481554550, -129585706407509744, -1095334179819280914, -425836646177174784], [-11825037112662521514753255, -14159694805349857697427, 620533363940669105792, 3416374852014733638, -3968719982562511851, 107288119026254016, -351008314668961863, -200158548549502164], [40019101507236664138054497, -48441918093159339309199, 623670548931507813664, 1487333496508051181, -2536088547016785331, -1285501112769249236, -2275191892628058463, -288654475098739104], [-14810918349259815414884066, -165391579256758616661408, 195431860453545045696, 7060393923634417192, 1987606694692965008, 1262225142922085352, 1418240925307478576, 164997949353035504], [-4619235820509977085643949, 114101156469575006852124, 982695428124682212598, -321079233999680657, -2527287107877550994, 124334866703503449, 3127077709546002690, 989716049230205916], [-8789630718976777848927452, 67861900619359771202314, -360350859521195719292, 5913626324702227913, -1682383276764196458, 1118401002453134304, -117258634563074610, -1381380552839107392], [-31521083045264561035634249, 53766805115755426814992, -55936168161576645962, 3093797942211121103, 661220859407812002, -284427448841047335, -2187326977777542074, -354294606034966932], [28029660784036369867507195, 13286634369757656089243, -160673589126434182208, 6266795358862449573, 123439543219568591, -154403005758985464, 2612313571259035739, 144482234787595296], [617206300348152616037583, -80831464695675304572939, -1112799239698204954276, -16349782723579287276, -976017926329938615, -737520407406034218, 680015423305302981, -919307711108633700], [11419361903591002119585215, 89255760425286524752130, -502564044653942692270, 3571444835969840003, -3576670466389948816, -1180547323047798789, 1024556211212231156, 294863042510551028], [-5969044421067813209864046, -35284207267444951775084, 738931404995077817048, -13448227788315746810, -2935153239852751892, -603430239353818360, -667159574810349764, 371070981618972336], [-54796149596251097982785608, -24909965536253776594912, 436854488301062842424, 1773611303136054278, 185669312286599864, 385789757753614056, -1647087761404487176, 386805761676615680], [-7744536852582969049526308, 36943339600705180762917, -261042698194976242818, -3970798806955357087, 7379752790809836567, 469464736914347077, 870211107989011215, -118807408992824856], [47579308985012868043989718, -89377122718309157343002, 645572021754803483056, -863755206991042008, 439011614461403750, -1507754500582025712, 1306427103761123294, -658733722953071224], [-11230999495351074742870350, -80678942820707035776019, 151100463009741128090, 4639308292117688121, -10303409161883782493, -951302480007975117, 1967956731860755939, -957697122408586704], [-38097071090162937279455878, -66517988001691901316766, -863458252895819734656, -1751536302941059368, 1307170056340701066, 2359760169117694788, 2279520627539043330, 285510502653743376], [-52623629246783476456520529, 147628854344748669263211, -331155214777687030048, -13164720001255130350, -4119285992608200317, -652058834750783856, -928994561149797761, -344476285279701740], [-11409363570242106457766840, 56493291795898866413230, 152490525626535114676, -12431893998385235462, -1280576894286252518, 461520460829178678, -1712392739639185142, 753273660915589744], [32265914386780620546450987, -216493614582590412925941, 310631912986142522352, 2405801215283227929, 12721338033934400943, 583723976759752104, -391729137428860869, 371090062722580704], [7233070022676733420845200, 12966480001686545152588, -218545398024971950648, 1950045004108337988, 509933587091934724, -2853899335629006564, -3103589422478025500, -607459193061248736], [3362780737828903881273926, 277296288263525933821244, 140741341626624403916, 10277029252226846641, 2772022344089292360, -58354355167053768, 1062837410327603208, -901065320637774048], [64102201374514088353195707, 26778677438372959838984, 165894982651563804782, -2545297635441484533, 5199525326608596130, -1073300990650521603, -288819514691216330, -758012944809388068], [-14393401562560264457198427, -234532833160316481511823, 1968778634300515178308, -3690951739931078154, 1259414997868175633, -218582170428418968, -1892707703598491323, -413653342033869264], [42279424871831191687338625, -113830291853032206481595, -104816833691279775760, -5739192646317688825, -7319489355792421247, 1822164770462444392, 1234894246951622773, 757581276023904096], [29429699861228734369091835, 174392685254294955339948, 316120916057640878262, -5185446230030048707, -11002175611489580330, -1852085838952979223, -454593113645592902, 226568003058198196], [19200977418960241987004203, 148852565332230314102107, 471904226853263807316, -2668313090230603884, 5074850244935623107, 1351060866651796848, 1985087842236057279, 1638274773432301200], [18717859307789900055494518, 264845078291682533191563, -1072095989356150980138, -10834066382025158639, -8011091744011016811, -211909940578965127, -172190831085609579, -149929353888537888], [22843521830012615936222316, 28493520091895417717886, -1164154568547466508676, -8236025252373363734, -8930042067087125710, 503537349717054690, 181731458118841394, -1282197652719108496], [-40809963410877090499184320, -35458514937962516418225, -93300026491881285086, 42784705806786796509, -249431324170428691, 264067856950914519, 1722973080858446021, 337716040752463032], [21089909861309734698716816, 294605848816002401890856, -970759548835758715848, -2009109688035418368, -4566691067926667088, -2670151751846350020, -1075858720538142144, 379021986829118448], [-18257481427941471088042650, 284444904934684224962460, -711037023618796771536, 7206761196963604944, -7338572259109871076, 485279920452719376, -3931596917051981940, -270651058995269376], [37108824764864737892369661, -239944045271439184846467, -1550881705890701371768, 42059267904928786162, 689998562725565405, -900401636168226324, 3794703110346219761, -65685273185532964], [51380898398948240337461378, -90196992031431294340878, 109821398461407974928, -13759332263423653324, 1629917948822080290, -1563140966791369520, 3880502790802201482, 242508203545114440]]
